<?php
session_start();

// If you update any logs, be sure to update it here.
$banned_file = "../chat/banned_file.txt";

// If they are not an admin
if(!isset($_SESSION['chat_admin']) || $_SESSION['chat_admin'] != 1) {
	header("Location: ../chat.php");
	die;
}

require("../config.php");

// If the settings form was submitted
if($_SERVER['REQUEST_METHOD'] === "POST" && isset($_POST['post_limit'], $_POST['ban_time'])) {

	// Check if the ban length and post limit are numerical
	if(!ctype_digit($_POST['post_limit']) || !ctype_digit($_POST['ban_time']))
		$error = "Post limit and Ban length must be numerical.";

	// Check if fields were filled in
	if(!isset($_POST['post_limit']) || !isset($_POST['ban_time']))
		$error = "Please fill in all fields.";
	
	// If there were no errors
	if(empty($error)) {
	
		require("../functions.php");
	
		$f = (isset($_POST['filter']) ? 1 : 0);
		$f_all = (isset($_POST['filter_all']) ? 1 : 0);
		$post_lim = htmlentities(round($_POST['post_limit']));
		$ban_t = htmlentities(round($_POST['ban_time']));
		
		// Update the settings
		chat_update($f, $f_all, $post_lim, $ban_t);
		$chat_success = 1;
	
	}

// If the unban form was submitted
} else if($_SERVER['REQUEST_METHOD'] === "POST" && isset($_POST['banned'])) {

	$select = explode(" ", $_POST['banned']);

	// Check if they did not select a user
	if(empty($_POST['banned']) || empty($select['0']))
		$ban_error = "Please select a user.";
		
	// For each line in the banned file
	foreach(file($banned_file) as $line_num => $line) {

		// If the line contains the session user
		if(strpos($line, $select['0']." ") !== false) {

			// Set $banned so we know they are in the file
			$banned = 1;
			$ban_line = $line_num + 1;

		}

	}
	
	if(!isset($banned) || $banned != 1)
		$ban_error = "The requested user is not banned";
		
	if(empty($ban_error)) {
	
		require("../functions.php");
		delete_message($ban_line, $banned_file);
		$ban_success = "User unbanned successfully!";
	
	}
	

// If the account form was submitted
} else if($_SERVER['REQUEST_METHOD'] === "POST" && isset($_POST['pass'], $_POST['c_pass'], $_POST['cur_pass'])) {

	// Check if the passwords match
	if($_POST['pass'] != $_POST['c_pass'])
		$account_error = "The two passwords do not match.";

	// Check if the password length is at least 6 characters
	if(strlen($_POST['pass']) < 6)
		$account_error = "Passwords must be a minimum of 6 characters.";

	// Check if fields were filled in
	if(empty($_POST['pass']) || empty($_POST['c_pass']) || empty($_POST['cur_pass']))
		$account_error = "Please fill in all fields.";

	// If there were no errors
	if(empty($account_error)) {

		include("../connect.php");
		require("../chat/functions.php");
		
		$user = mysqli_real_escape_string($connection, $_SESSION['chat_user']);
		$pass = Secure($_POST['cur_pass']);
		
		$sql = mysqli_query($connection, "SELECT `user` FROM `chat_users` WHERE `user` = '{$user}' AND `pass` = '{$pass}'");
		mysqli_close($connection);

		// If the current password is incorrect
		if(mysqli_num_rows($sql) == 0)
			$account_error = "Current password is incorrect.";
		
		// If there were no errors
		if(empty($account_error)) {

			require("../functions.php");

			// Update the user
			update_user(Secure($_POST['pass']));
			
		}

	}

}
?>
<!DOCTYPE html>
<html>

<head>

	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

	<title>MDCode | Chat</title>
	
	<link href="../css/bootstrap.css" rel="stylesheet" type="text/css" />
	<link href="../css/chat.css" rel="stylesheet" type="text/css" />

</head>

<body>
	
<h1 style="text-align: center;">MDCode Chat | Admin</h1>
	
<div class="container">

	<div class="row">

		<div class="span8 offset2 well" style="position: relative; text-align: center;">
		
			<a href="../chat.php" class="btn btn-mini" style="position: absolute; top: 15px; left: 15px;">Back to Chat</a>
			
			<h4>Chat Configurations</h4>
			
			<?php
			if(isset($error))
				echo "<div class='alert alert-error'><b>ERROR</b>: $error</div>";
			else if(isset($chat_success) && $chat_success == 1)
				echo "<div class='alert alert-success'><b>SUCCESS</b>: Chat settings upated successfully!</div>";
			?>

			<form method="post">

				<label class="checkbox">
					<?php
					if(isset($_POST['filter']) && $_POST['filter'] == "Yes")
						echo '<input type="checkbox" name="filter" value="Yes" checked>';
					else if($_SERVER['REQUEST_METHOD'] === "POST" && !isset($_POST['filter']))
						echo '<input type="checkbox" name="filter" value="Yes">';
					else
					?>
					<input type="checkbox" name="filter" value="Yes" <?php echo (($filter == 1) ? 'checked' : ''); ?>>
				
					Filter Chat <a id="filter" class="btn btn-mini btn-inverse">?</a>
				</label>
				
				
				<label class="checkbox">
					<?php
					if(isset($_POST['filter_all']) && $_POST['filter_all'] == "Yes")
						echo '<input type="checkbox" name="filter_all" value="Yes" checked>';
					else if($_SERVER['REQUEST_METHOD'] === "POST" && !isset($_POST['filter_all']))
						echo '<input type="checkbox" name="filter_all" value="Yes">';
					else
					?>
					<input type="checkbox" name="filter_all" value="Yes" <?php echo (($filter_all == 1) ? 'checked' : ''); ?>>
				
					Filter All Matches <a id="filter_all" class="btn btn-mini btn-inverse">?</a>
				</label>
				
				<div class="option">
					Post limit before ban: <input type="text" class="span5" name="post_limit" value="<?php echo ( (isset($_POST['post_limit']) && ctype_digit($_POST['post_limit']) ) ? htmlentities($_POST['post_limit']) : htmlentities($post_limit) ); ?>"> <a id="post_limit" class="btn btn-mini btn-inverse" style="margin-bottom: 10px;">?</a>
				</div>
				
				<div class="option">				
					Ban length: <input type="text" class="span5" name="ban_time" value="<?php echo ( (isset($_POST['ban_time']) && ctype_digit($_POST['ban_time']) ) ? htmlentities($_POST['ban_time']) : htmlentities($ban_time) ); ?>" style="margin-left: 62px;"> <a id="ban_length" class="btn btn-mini btn-inverse" style="margin-bottom: 10px;">?</a>		
				</div>
				
				<button type="submit" class="btn btn-inverse btn-block">Submit</button>
				
			</form>
			
			
			<h4>Banned Members</h4>
			
			<?php
			if(isset($ban_error))
				echo "<div class='alert alert-error'><b>ERROR</b>: $ban_error</div>";
			else if(isset($ban_success))
				echo "<div class='alert alert-success'><b>SUCCESS</b>: $ban_success</div>";
			?>
			
			<form method="post">
			
				<select name="banned" size="5">
					<?php
					foreach(file($banned_file) as $line_num => $line) {

						if($line != "\n") {
					
							$receiver = explode(" ", $line);
							$time_left = ceil(($receiver['1'] + ($receiver['2'] * 60) - time()) / 60);
					
							echo "<option>".htmlentities($receiver['0'])." - ".$time_left." minute(s) remaining.</option>";
				
						}
				
					}
					?>
				</select>
				
				<button type="submit" class="btn btn-inverse btn-block">Unban Member</button>
			
			</form>
			
			</select>

			
			<h4>Account options</h4>
			
			<?php
			if(isset($account_error))
				echo "<div class='alert alert-error'><b>ERROR</b>: $account_error</div>";
			?>

			<form method="post">

				<input type="password" class="span3" name="pass" placeholder="New Password">
				<input type="password" class="span3" name="c_pass" placeholder="Confirm Password">
				
				<input type="password" class="span3" name="cur_pass" placeholder="Current Password">
				
				<button type="submit" class="btn btn-inverse btn-block">Change Password</button>
				
			</form>
		
		</div>

	</div>

</div>

<script src="https://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js"></script>
<script type="text/javascript" src="../js/tooltip.js"></script>
<script type="text/javascript" src="../js/popover.js"></script>

<script>
$('#filter').popover({ title : 'Filter Chat', content: 'Censor all inappropriate whole-words.  Customizable list can be found in functions.php under function filter()', placement : 'right', trigger : 'hover' });
$('#filter_all').popover({ title : 'Filter All', content: 'If yes, chat will no longer only censor whole-words such as "rain".  Non-whole words like "rainbow" will censor "rain".', placement : 'right', trigger: 'hover' });
$('#post_limit').popover({ title : 'Post limit', content: 'The amount of posts (within a 3 second interval each) before a user is banned.', placement : 'right', trigger: 'hover' });
$('#ban_length').popover({ title : 'Ban Length', content: 'How long do you want a ban to last? (In minutes)', placement : 'right', trigger: 'hover' });
</script>
	

</body>
</html>